@@ -156,7 +156,7 @@
 
 
 ;;; History:
-;; 
+;;
 
 ;; 1.3  - modified logic that determines old or new style Debian packages.
 ;;        On systems where the file command recognizes debian files, it
@@ -230,6 +230,9 @@
 
 ;;; Code:
 
+(require 'tar-mode)
+(require 'dired)
+
 (defgroup deb-view nil
   "View Debian package files with tar-mode"
   :group 'tools
@@ -252,7 +255,7 @@ See also the variable deb-find-directory."
   :group 'deb-view
   :type '(radio (const "find") (const "locate")))
 
-(defcustom deb-find-directory "/usr/local/src/debian"
+(defcustom deb-find-directory "/var/cache/apt/archives"
   "Directory to run find in when deb-find-method is \"find\"."
   :group 'deb-view
   :type 'directory)
@@ -295,12 +298,7 @@ See also the variable deb-find-directory."
   "The file name being processed by `deb-view'.")
 
 ;; You might not like the key bindings that I chose:
-(if (featurep 'dired)
-    (define-key dired-mode-map "\C-d" 'deb-view-dired-view)
-  (add-hook
-   'dired-load-hook
-   (function (lambda ()
-               (define-key dired-mode-map "\C-d" 'deb-view-dired-view)))))
+(define-key dired-mode-map "\C-d" 'deb-view-dired-view)
 
 ;;;###autoload
 (defun deb-view-dired-view ()
@@ -356,8 +354,7 @@ at the prompt."
     ;; info
     (setq file-buffer (get-buffer-create " *file-data*"))
     (setq new-archive-format
-          (save-excursion
-            (set-buffer file-buffer)
+          (with-current-buffer file-buffer
             (erase-buffer)
             (call-process "file" nil '(t t) debfile)
             (goto-char 1)
@@ -378,7 +375,8 @@ at the prompt."
       (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
       (debview-mode)
       ;; Turn off view-mode in this buffer:
-      (make-variable-buffer-local 'view-mode-hook)
+      (make-local-variable 'view-mode-hook)
+      (make-local-variable 'view-exit-action)
       (add-hook
        'view-mode-hook
        (function (lambda ()
@@ -414,7 +412,7 @@ at the prompt."
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "gzip" t t nil "-cd"))
        ((and (goto-char 1)(re-search-forward "data.tar.bz2" nil t))
@@ -423,19 +421,28 @@ at the prompt."
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "bzip2" t t nil "-cd"))
+       ((and (goto-char 1)(re-search-forward "data.tar.zst" nil t))
+        (erase-buffer)
+        (call-process "ar" nil '(t t) nil "-p" debfile "data.tar.zst")
+        (goto-char (point-max))
+        (when (search-backward "is not a valid archive" nil t)
+          (kill-buffer data-buffer)
+          (kill-buffer info-buffer)
+          (error "%s: Not a valid package file" deb-view-buffer-name))
+        (call-process-region (point-min) (point-max) "zstd" t t nil "-cd"))
        ((and (goto-char 1)(re-search-forward "data.tar.xz" nil t))
         (erase-buffer)
         (call-process "ar" nil '(t t) nil "-p" debfile "data.tar.xz")
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "xz" t t nil "-cd"))))
-     (t      
+     (t
       (call-process "dpkg-deb" '(t t) nil "--fsys-tarfile " debfile)))
     (goto-char 1)
     (setq buffer-file-name (concat deb-view-file-name "-DATA"))
@@ -485,7 +492,7 @@ output in a buffer.  See also the variable deb-find-directory.
 This command uses a special history list, so you can
 easily repeat a `deb-find' command."
   (interactive)
-  (require 'compile)
+  (eval-and-compile (require 'compile))
   (let* ((deb-file-string (read-from-minibuffer "deb file to find: "
 						nil nil nil 'deb-find-history))
          (output-buffer-name "*deb-find*")
@@ -497,9 +504,9 @@ easily repeat a `deb-find' command."
                                  deb-file-string "' | egrep '\.deb$'"))
                         (t
                          (concat deb-find-method " '" deb-file-string "'")))))
-    (compile-internal command "Not applicable in deb-find" "deb-find" nil nil
-                      (function (lambda (mode) output-buffer-name)))
+    (compilation-start command nil (lambda (mode) output-buffer-name))
     (switch-to-buffer-other-window output-buffer-name)
+    (make-local-variable 'deb-view-find-minor-mode-map)
     (setq deb-view-find-minor-mode-map
           (copy-keymap compilation-minor-mode-map))
     (use-local-map deb-view-find-minor-mode-map)
@@ -513,7 +520,7 @@ easily repeat a `deb-find' command."
     (define-key deb-view-find-minor-mode-map "\M-p" 'undefined)
     (define-key deb-view-find-minor-mode-map "\M-{" 'undefined)
     (define-key deb-view-find-minor-mode-map "\M-}" 'undefined)
-    (beginning-of-buffer)
+    (goto-char (point-min))
     (message "deb-view: ? for help. q to quit.")))
 
 
@@ -526,7 +533,7 @@ easily repeat a `deb-find' command."
   "Return string describing the version of `deb-view'.
 When called interactively, displays the version."
   (interactive)
-  (if (interactive-p)
+  (if (called-interactively-p 'interactive)
       (message "deb-view version %s" (deb-view-version))
     deb-view-version))
 
@@ -538,8 +545,7 @@ When called interactively, displays the version."
          (debfile (substring bufname 0 (- (length bufname) 5)))
          (info-buffer (get-buffer (concat debfile "-INFO")))
          (data-buffer (get-buffer (concat debfile "-DATA")))
-         (ddir-buffer (save-excursion
-                        (set-buffer quit-buffer)
+         (ddir-buffer (with-current-buffer quit-buffer
                         deb-view-dired-view-return-buffer)))
     (delete-other-windows)
     (and (buffer-live-p info-buffer)
@@ -562,10 +568,9 @@ C-c C-c - view the deb file on this line with deb-view.
 mouse-2 - view the deb file on this line with deb-view.
 ? - show deb-find-help.
 q - quit deb-find.")
-    (save-excursion
-      (set-buffer standard-output)
+    (with-current-buffer standard-output
       (help-mode))
-    (print-help-return-message)))
+    (help-print-return-message)))
 
 (defun deb-view-help ()
   "Show help information for `deb-view'."
@@ -598,15 +603,14 @@ when deb-view is loaded.
 To view files not supported by deb-view, such as graphics, use the
 copy command in tar-mode (\"c\") to copy the file to a temp directory.
 You can then do what you want to the file.")
-    (save-excursion
-      (set-buffer standard-output)
+    (with-current-buffer standard-output
       (help-mode))
-    (print-help-return-message)))
+    (help-print-return-message)))
 
 (defun deb-view-tar-man ()
   "*In Tar mode, view the tar file entry on this line as a man page."
   (interactive)
-  (require 'man)
+  (eval-and-compile (require 'man))
   (let ((auto-mode-alist
          (append '(("\\.gz$" . deb-view-tar-uncompress-while-visiting)
                    ("\\.Z$"  . deb-view-tar-uncompress-while-visiting)
